CCA
===

.. currentmodule:: xeofs.cross

.. autoclass:: CCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CCA.__init__
      ~CCA.components
      ~CCA.compute
      ~CCA.correlation_coefficients_X
      ~CCA.correlation_coefficients_Y
      ~CCA.cross_correlation_coefficients
      ~CCA.deserialize
      ~CCA.fit
      ~CCA.fraction_variance_X_explained_by_X
      ~CCA.fraction_variance_Y_explained_by_X
      ~CCA.fraction_variance_Y_explained_by_Y
      ~CCA.get_params
      ~CCA.get_serialization_attrs
      ~CCA.heterogeneous_patterns
      ~CCA.homogeneous_patterns
      ~CCA.inverse_transform
      ~CCA.load
      ~CCA.predict
      ~CCA.save
      ~CCA.scores
      ~CCA.serialize
      ~CCA.squared_covariance_fraction
      ~CCA.transform
   
   

   
   
   